@@ -1,7 +1,7 @@
 program SEQ
 ! Pendergrass_Willoughby 2009 Υ䡼ꥢåǥ
   use derivation
-  use alge_solv
+  use Ellip_Slv
   use file_operate
   use gtool_history
   use Thermo_Const
@@ -325,11 +325,11 @@ end do
 
 !-- ݥ󥽥
 
-  call Poisson_Jacobi( r(1:nr), z(1:nz), force(1:nr,1:nz), eps,  &
-  &                    bc, psi(1:nr,1:nz), bound(1:nr,1:nz),  &
-  &                    a=term1(1:nr,1:nz),  b=term2(1:nr,1:nz),  &
-  &                    c=term3(1:nr,1:nz),  d=term4(1:nr,1:nz),  &
-  &                    e=term5(1:nr,1:nz)) 
+  call Ellip_Jacobi_2d( r(1:nr), z(1:nz), force(1:nr,1:nz), eps,  &
+  &                     bc, psi(1:nr,1:nz), bound(1:nr,1:nz),  &
+  &                     a=term1(1:nr,1:nz),  b=term2(1:nr,1:nz),  &
+  &                     c=term3(1:nr,1:nz),  d=term4(1:nr,1:nz),  &
+  &                     e=term5(1:nr,1:nz)) 
 
 !-- ήؿ 2 ۴Ĥη׻
 
