@@ -12,7 +12,9 @@ program sound_make
 
 !-- namelist valiables
   integer :: nr, nz  ! ʿľʻ
-  real :: dr, dz  ! бʻҴֳ
+  integer :: mom_flag
+  real :: coril
+  real :: dr, dz     ! ʿľʻҴֳ [m]
   character(4) :: bc  ! not use
   character(80) :: fname  ! not use
   character(80) :: sound_name  ! ǥ󥰥ե̾
@@ -31,7 +33,7 @@ program sound_make
   integer :: i
 
 !-- namelist Υѥ᡼
-  namelist /input /nr, nz, dr, dz, bc, fname, sound_name
+  namelist /input /nr, nz, dr, dz, bc, fname, sound_name, coril, mom_flag
   read(5,nml=input)
 
 !-- allocate
