@@ -126,7 +126,8 @@ program draw
   call nearest_search_1d( y, ymin, ydmin )
   call nearest_search_1d( y, ymax, ydmax )
 
-  xscale=0.025
+  xscale=0.05/vxfact
+!  xscale=0.025
   call calc_vscale( (/(xmax-xmin), (ymax-ymin)/), (/0.6, 0.6/), xscale, yscale )
 !  yscale=yscale
 
