@@ -1,6 +1,6 @@
 program Thorpe
   use gtool_history
-  use Alge_Solv
+  use Ellip_Slv
   use Derivation
   use geometry
 
@@ -77,9 +77,9 @@ program Thorpe
 
   select case (method)
   case(1)
-     call Poisson_GauSei(x,y,rho,1.0e-6,tp,psi)
+     call Ellip_GauSei_2d(x,y,rho,1.0e-6,tp,psi)
   case(2)
-     call Poisson_Jacobi(x,y,rho,1.0e-6,tp,psi)
+     call Ellip_Jacobi_2d(x,y,rho,1.0e-6,tp,psi)
   end select
 
 !-- ݥƥ󥷥륢Υޥ꡼Ϲη׻
