@@ -1,6 +1,6 @@
 program poison
   use gtool_history
-  use Alge_Solv
+  use Ellip_Slv
 
   implicit none
 
@@ -66,18 +66,18 @@ program poison
      ib(nx*3/4,1:ny/3)=1
      select case (method)
      case(1)
-        call Poisson_GauSei( x, y, rho, 1.0e-6, tp, psi,  &
+        call Ellip_GauSei_2d( x, y, rho, 1.0e-6, tp, psi,  &
   &                          inner_bound=ib, undef=undef )
      case(2)
-        call Poisson_Jacobi( x, y, rho, 1.0e-6, tp, psi,  &
+        call Ellip_Jacobi_2d( x, y, rho, 1.0e-6, tp, psi,  &
   &                          inner_bound=ib, undef=undef )
      end select
   else
      select case (method)
      case(1)
-        call Poisson_GauSei(x,y,rho,1.0e-6,tp,psi)
+        call Ellip_GauSei_2d(x,y,rho,1.0e-6,tp,psi)
      case(2)
-        call Poisson_Jacobi(x,y,rho,1.0e-6,tp,psi)
+        call Ellip_Jacobi_2d(x,y,rho,1.0e-6,tp,psi)
      end select
   end if
 
