@@ -636,7 +636,7 @@ subroutine interpo_search_1d( x, point, i, undeff, stdopt )
      if(x(1)>point)then
         if(stderr.eqv..false.)then
            write(*,*) "****** WARNING ******"
-           write(*,*) "searching point was not found."
+           write(*,*) "searching point was not found :", x(1), point
            write(*,*) "Abort. Exit.!!!"
         end if
         i=just
@@ -880,6 +880,8 @@ subroutine auto_interpolation_1d( x, r, u, v, undef, undefr, stdopt )
 
   if(present(undefr))then
      rdefun=undefr
+  else
+     rdefun=-999.0
   end if
 
   if(present(stdopt))then
@@ -891,11 +893,17 @@ subroutine auto_interpolation_1d( x, r, u, v, undef, undefr, stdopt )
   do i=1, nr
      call interpo_search_1d( x, r(i), ir, int(defun), stdopt=stderr )
 
-     if(ir/=int(defun).and.ir<nx)then
-        if(u(ir)/=rdefun.and.u(ir+1)/=rdefun)then
-           call interpolation_1d( x(ir:ir+1), u(ir:ir+1), r(i), v(i) )
+     if(ir/=int(defun))then
+        if(ir<nx)then
+           if(u(ir)/=rdefun.and.u(ir+1)/=rdefun)then
+              call interpolation_1d( x(ir:ir+1), u(ir:ir+1), r(i), v(i) )
+           else
+              v(i)=rdefun
+           end if
+        else if(ir==nx.and.x(nx)==r(i))then
+           v(i)=u(ir)
         else
-           v(i)=rdefun
+           v(i)=real(defun)
         end if
      else
         v(i)=real(defun)
@@ -939,6 +947,8 @@ subroutine auto_interpolation_2d( x, y, r, q, u, v, undef, undefr, stdopt )
 
   if(present(undefr))then
      rdefun=undefr
+  else
+     rdefun=-999.0
   end if
 
   if(present(stdopt))then
@@ -952,15 +962,45 @@ subroutine auto_interpolation_2d( x, y, r, q, u, v, undef, undefr, stdopt )
         call interpo_search_2d( x, y, r(i), q(j), ir, iq, int(defun),  &
   &                             stdopt=stderr )
 
-        if(ir/=int(defun).and.iq/=int(defun).and.ir<nx.and.iq<ny)then
-           if(u(ir,iq)/=rdefun.and.u(ir+1,iq)/=rdefun.and.  &
-  &           v(ir,iq+1)/=rdefun.and.v(ir+1,iq+1)/=rdefun)then
-              call interpolation_2d( x(ir:ir+1), y(iq:iq+1),  &
-  &                              u(ir:ir+1,iq:iq+1), (/r(i), q(j)/), v(i,j) )
+        if(ir/=int(defun).and.iq/=int(defun))then
+           if(u(ir,iq)/=rdefun)then
+              if(ir<nx.and.iq<ny)then
+                 if(u(ir,iq+1)/=rdefun.and.u(ir+1,iq+1)/=rdefun.and.  &
+  &                 u(ir+1,iq+1)/=rdefun)then
+                    call interpolation_2d( x(ir:ir+1), y(iq:iq+1),  &
+  &                                        u(ir:ir+1,iq:iq+1),  &
+  &                                        (/r(i), q(j)/), v(i,j) )
+                 else
+                    v(i,j)=rdefun
+                 end if
+
+              else if(x(nx)==r(i).and.y(ny)==q(j))then
+                 v(i,j)=u(nx,ny)
+
+              else if(x(nx)==r(i).and.iq<ny)then
+                 if(u(nx,iq+1)/=rdefun)then
+                    call interpolation_1d( y(iq:iq+1), u(nx,iq:iq+1),  &
+  &                                        q(j), v(i,j) )
+                 else
+                    v(i,j)=rdefun
+                 end if
+
+              else if(y(ny)==q(j).and.ir<nx)then
+                 if(u(ir+1,ny)/=rdefun)then
+                    call interpolation_1d( x(ir:ir+1), u(ir:ir+1,ny),  &
+  &                                        r(i), v(i,j) )
+                 else
+                    v(i,j)=rdefun
+                 end if
+              else
+write(*,*) "kokonihakonaihazu1", x(nx), r(i), y(ny), q(j), ir, nx, iq, ny
+                 v(i,j)=real(defun)
+              end if
            else
               v(i,j)=rdefun
            end if
         else
+write(*,*) "kokonihakonaihazu2", x(nx), r(i), y(ny), q(j), ir, nx, iq, ny
            v(i,j)=real(defun)
         end if
      end do
@@ -1007,6 +1047,8 @@ subroutine auto_interpolation_3d( x, y, z, r, q, p, u, v, undef, undefr, stdopt
 
   if(present(undefr))then
      rdefun=undefr
+  else
+     rdefun=-999.0
   end if
 
   if(present(stdopt))then
@@ -1021,15 +1063,86 @@ subroutine auto_interpolation_3d( x, y, z, r, q, p, u, v, undef, undefr, stdopt
            call interpo_search_3d( x, y, z, r(i), q(j), p(k),  &
   &                                ir, iq, ip, int(defun), stdopt=stderr )
 
-           if(ir/=int(defun).and.iq/=int(defun).and.ip/=int(defun).and.  &
-  &           ir<nx.and.iq<ny.and.ip<nz)then
-              if(u(ir,iq,ip)/=rdefun.and.u(ir+1,iq,ip)/=rdefun.and.  &
-  &              u(ir,iq+1,ip)/=rdefun.and.u(ir+1,iq+1,ip)/=rdefun.and.  &
-  &              u(ir,iq,ip+1)/=rdefun.and.u(ir+1,iq,ip+1)/=rdefun.and.  &
-  &              u(ir,iq+1,ip+1)/=rdefun.and.u(ir+1,iq+1,ip+1)/=rdefun)then
-                 call interpolation_3d( x(ir:ir+1), y(iq:iq+1), z(ip:ip+1),  &
-  &                                  u(ir:ir+1,iq:iq+1,ip:ip+1),  &
-  &                                  (/r(i), q(j), p(k)/), v(i,j,k) )
+           if(ir/=int(defun).and.iq/=int(defun).and.ip/=int(defun))then
+              if(u(ir,iq,ip)/=rdefun)then
+                 if(ir<nx.and.iq<ny.and.ip<nz)then
+                    if(u(ir+1,iq,ip)/=rdefun.and.  &
+  &                    u(ir,iq+1,ip)/=rdefun.and.  &
+  &                    u(ir+1,iq+1,ip)/=rdefun.and.  &
+  &                    u(ir,iq,ip+1)/=rdefun.and.  &
+  &                    u(ir+1,iq,ip+1)/=rdefun.and.  &
+  &                    u(ir,iq+1,ip+1)/=rdefun.and.  &
+  &                    u(ir+1,iq+1,ip+1)/=rdefun)then
+                       call interpolation_3d( x(ir:ir+1), y(iq:iq+1), z(ip:ip+1),  &
+  &                                        u(ir:ir+1,iq:iq+1,ip:ip+1),  &
+  &                                        (/r(i), q(j), p(k)/), v(i,j,k) )
+                    else
+                       v(i,j,k)=rdefun
+                    end if
+
+                 else if(x(nx)==r(i).and.y(ny)==q(j).and.z(nz)==p(k))then
+                    v(i,j,k)=u(ir,iq,ip)
+
+                 else if(x(nx)==r(i).and.iq<ny.and.ip<nz)then
+                    if(u(nx,iq+1,ip)/=rdefun.and.u(nx,iq,ip+1)/=rdefun.and.  &
+  &                    u(nx,iq+1,ip+1)/=rdefun)then
+                       call interpolation_2d( y(iq:iq+1), z(ip:ip+1),  &
+  &                                           u(nx,iq:iq+1,ip:ip+1),  &
+  &                                           (/q(j), p(k)/), v(i,j,k) )
+                    else
+                       v(i,j,k)=rdefun
+                    end if
+
+                 else if(y(ny)==q(j).and.ir<nx.and.ip<nz)then
+                    if(u(ir+1,ny,ip)/=rdefun.and.u(ir,ny,ip+1)/=rdefun.and.  &
+  &                    u(ir+1,ny,ip+1)/=rdefun)then
+                       call interpolation_2d( x(ir:ir+1), z(ip:ip+1),  &
+  &                                           u(ir:ir+1,ny,ip:ip+1),  &
+  &                                           (/r(i), p(k)/), v(i,j,k) )
+                    else
+                       v(i,j,k)=rdefun
+                    end if
+
+                 else if(z(nz)==p(k).and.ir<nx.and.iq<ny)then
+                    if(u(ir+1,iq,nz)/=rdefun.and.u(ir,iq+1,nz)/=rdefun.and.  &
+  &                    u(ir+1,iq+1,nz)/=rdefun)then
+                       call interpolation_2d( x(ir:ir+1), y(iq:iq+1),  &
+  &                                           u(ir:ir+1,iq:iq+1,nz),  &
+  &                                           (/r(i), q(j)/), v(i,j,k) )
+                    else
+                       v(i,j,k)=rdefun
+                    end if
+
+                 else if(x(nx)==r(i).and.y(ny)==q(j).and.ip<nz)then
+                    if(u(nx,ny,ip+1)/=rdefun)then
+                       call interpolation_1d( z(ip:ip+1),  &
+  &                                           u(nx,ny,ip:ip+1),  &
+  &                                           p(k), v(i,j,k) )
+                    else
+                       v(i,j,k)=rdefun
+                    end if
+
+                 else if(x(nx)==r(i).and.z(nz)==p(k).and.iq<ny)then
+                    if(u(nx,iq+1,nz)/=rdefun)then
+                       call interpolation_1d( y(iq:iq+1),  &
+  &                                           u(nx,iq:iq+1,nz),  &
+  &                                           q(j), v(i,j,k) )
+                    else
+                       v(i,j,k)=rdefun
+                    end if
+
+                 else if(y(ny)==q(j).and.z(nz)==p(k).and.ir<nx)then
+                    if(u(ir+1,ny,nz)/=rdefun)then
+                       call interpolation_1d( x(ir:ir+1),  &
+  &                                           u(ir:ir+1,ny,nz),  &
+  &                                           r(i), v(i,j,k) )
+                    else
+                       v(i,j,k)=rdefun
+                    end if
+
+                 else
+                    v(i,j,k)=real(defun)
+                 end if
               else
                  v(i,j,k)=rdefun
               end if
@@ -1906,7 +2019,7 @@ end subroutine smooth_3d
 !---------------------------------
 !---------------------------------
 
-subroutine Move_ave( x, n, y, error )
+subroutine Move_ave( x, n, y, error, offset )
 ! ưʿѤ׻롼
   implicit none
   real, intent(in) :: x(:)  ! ǡ
@@ -1914,33 +2027,56 @@ subroutine Move_ave( x, n, y, error )
   real, intent(inout) :: y(size(x))  ! ʿѲΥǡ.
                       ! ºݤ, y(1:n-1) ޤǤˤϥ.
   real, intent(in), optional :: error  ! »
-  integer :: nx, i
+  integer, intent(in), optional :: offset  ! ưʿѤ򳫻Ϥֹ.
+                      ! default = n
+  integer :: nx, i, ioff
   real :: tmp
 
   nx=size(x)
+  y=0.0
 
   if(nx<n.or.n<2)then
      write(*,*) "### ERROR ### (Move_ave)"
      write(*,*) "x(nx) : nx must be more than n or n must be more than 2."
+     write(*,*) "nx is ", nx, ", n is ", n, "."
      write(*,*) "STOP"
      stop
   end if
 
+  if(present(offset))then
+     if(offset>0)then
+        ioff=offset
+     else
+        write(*,*) "### ERROR ### (Move_ave)"
+        write(*,*) "offset must be more than 1."
+        write(*,*) "STOP"
+        stop
+     end if
+  else
+     ioff=n
+  end if
+
   if(present(error))then
      call Mean_1d( x(1:n), tmp, error )
-     y(1:n-1)=0.0
-     y(n)=tmp
+     if(ioff>2)then
+        y(1:ioff-1)=0.0
+        y(nx-n+ioff+1:nx)=0.0
+     end if
+     y(ioff)=tmp
 
-     do i=n+1,nx
-        y(i)=y(i-1)+(x(i)-x(i-n))/real(n)
+     do i=ioff+1,nx-n+ioff
+        y(i)=y(i-1)+(x(i+n-ioff)-x(i-ioff))/real(n)
      end do
   else
      call Mean_1d( x(1:n), tmp )
-     y(1:n-1)=0.0
-     y(n)=tmp
+     if(ioff>2)then
+        y(1:ioff-1)=0.0
+        y(nx-n+ioff+1:nx)=0.0
+     end if
+     y(ioff)=tmp
 
-     do i=n+1,nx
-        y(i)=y(i-1)+(x(i)-x(i-n))/real(n)
+     do i=ioff+1,nx-n+ioff
+        y(i)=y(i-1)+(x(i+n-ioff)-x(i-ioff))/real(n)
      end do
   end if
 
@@ -1949,6 +2085,65 @@ end subroutine Move_ave
 !---------------------------------
 !---------------------------------
 
+subroutine Move_anom( x, n, y, error, offset )
+! ưʿѤΥΥޥ׻롼
+  implicit none
+  real, intent(in) :: x(:)  ! ǡ
+  integer, intent(in) :: n  ! ʿѤȤ
+  real, intent(inout) :: y(size(x))  ! ʿѲΥǡ.
+                      ! ºݤ, y(1:n-1) ޤǤˤϥ.
+  real, intent(in), optional :: error  ! »
+  integer, intent(in), optional :: offset  ! ưʿѤ򳫻Ϥֹ.
+                      ! default = n
+  integer :: nx, i, ioff
+  real :: tmp, undef
+  real :: bar(size(x))
+
+  nx=size(x)
+  y=0.0
+
+  if(nx<n.or.n<2)then
+     write(*,*) "### ERROR ### (Move_anom)"
+     write(*,*) "x(nx) : nx must be more than n or n must be more than 2."
+     write(*,*) "nx is ", nx, ", n is ", n, "."
+     write(*,*) "STOP"
+     stop
+  end if
+
+  if(present(offset))then
+     if(offset>0)then
+        ioff=offset
+     else
+        write(*,*) "### ERROR ### (Move_anom)"
+        write(*,*) "offset must be more than 1."
+        write(*,*) "STOP"
+        stop
+     end if
+  else
+     ioff=n
+  end if
+
+  if(present(error))then
+     undef=error
+  else
+     undef=0.0
+  end if
+
+  call Move_ave( x, n, bar, error=undef, offset=ioff )
+
+  if(ioff>2)then
+     y(1:ioff-1)=0.0
+     y(nx-n+ioff+1:nx)=0.0
+  end if
+  do i=ioff,nx-n+ioff
+     y(i)=x(i)-bar(i)
+  end do
+
+end subroutine Move_anom
+
+!---------------------------------
+!---------------------------------
+
 subroutine Bubble_Sort_i( a, b, sig )
 ! Х֥륽ȤѤƿͥǡ sig ˥Ȥ.
   implicit none
