@@ -12,8 +12,193 @@ module typhoon_analy  ! ټ¸ѥڥϥ⥸塼
 
 contains
 
+subroutine tangent_conv_scal( x, y, xc, yc, u, r, theta, v, undef,  &
+  &                           undefg, undefgc, stdopt, axis )
+  ! Ǥդʪ̤濴ʿѤ, ΥΥޥ꡼׻롼
+  ! ¤Ȥ, |x(1)-xc|, |xc-x(nx)|, |y(1)-yc|, |yc-y(ny)| > r. 
+  ! ʳξ, r ͿΥΰ賰ϰϤˤĤƤ
+  ! undef ꤵ줿ͤ. undef ʤȤϥ.
+  ! ʿѲμϰʲΤȤ.
+  ! (1) nr, nt Τ٤ƤˤĤƤб x, y ɸͤ rt_2_xy Ƿ׻.
+  ! (2) ޤ x,y åɤΰ interpo_search_2d Ǹ.
+  ! (3) ޤ 4 Ф, ǤΥ顼ͤ 4 Υ顼
+  !     ,  interpolation_2d Ƿ׻.
+  ! ܥ롼ʿ̶˺ɸåͤǤк׻Ԥ.
+  ! ʿѤԤäΤ, ǥȺɸкȤˤ, 
+  ! tangent_mean_anom_scal_r2c .
+  ! ʲ, Թǽ꡹ present(undefg) äƤ뤬,
+  ! ʽˤϴطʤΤ, ɤ, present(undefg)  else
+  ! βս򻲾Ȥ줿.
+  use algebra
+  use Derivation
+  use max_min
+  use statistics
+  use Geometry
+  use Map_Function
+  implicit none
+  real, intent(in) :: x(:)  ! ɸϤǤʬ [m or rad]
+  real, intent(in) :: y(:)  ! ɸϤǤʬ [m or rad]
+  real, intent(in) :: u(size(x),size(y))  ! ɸϤǤʿѲ
+  real, intent(in) :: xc  ! ʿѤݤ濴 x ʬ. [m or rad]
+  real, intent(in) :: yc  ! ʿѤݤ濴 y ʬ. [m or rad]
+  real, intent(in) :: r(:)  ! (xc, yc) 濴Ȥ˺ɸưºɸ [m].
+  real, intent(in) :: theta(:)  ! (xc, yc) 濴Ȥ˺ɸƱ̳Ѻɸ [rad].
+  real, intent(inout) :: v(size(r),size(theta))  ! ʿѲ u ΥΥޥ꡼.
+  real, intent(in), optional :: undef  ! ΰ賰
+  real, intent(in), optional :: undefg  ! ʻ˷»̤
+  character(3), intent(in), optional :: undefgc  ! undefg ν
+                ! "inc" = γʻ򻲾ͤȤޤΤʿ˽Ʒ׻.
+                ! "err" = γʻ򻲾ͤȤޤʿ˴ޤ, ʿͤΤΤ̤ȤƷ׻. ξ, ̤ͤ undefg Ȥʤ.
+                ! ǥեȤ "inc".
+  logical, intent(in), optional :: stdopt  ! õϰϤĤʤݤɸϤɽʤ褦ˤ.
+                                           ! default Ǥ .false. (ɽ)
+  character(2), intent(in), optional :: axis  ! x, y κɸ
+                                           ! 'xy' = ǥȺɸ [m]
+                                           ! 'll' = ̰ٷٺɸ [rad]
+                                           ! ǥեȤ 'xy'.
+  integer :: i, j, nx, ny, nr, nt, i_undef, i_undefg
+  real :: r_undef, r_undefg
+  real :: work(size(r),size(theta))
+  real :: point(size(r),size(theta),2)
+  integer :: ip(size(r),size(theta),2)
+  real :: tmpx(2), tmpy(2), tmpz(2,2), inter(2)
+  character(1) :: undefgcflag
+  character(2) :: ax_flag
+  logical, dimension(size(r)) :: undefgc_check
+  logical :: ucf, stderr
+
+  nx=size(x)
+  ny=size(y)
+  nr=size(r)
+  nt=size(theta)
+
+  undefgc_check(:)=.true.
+
+  if(present(undef))then
+    i_undef=int(undef)
+    r_undef=undef
+  else
+    i_undef=-999
+    r_undef=-999.0
+  end if
+
+  if(present(undefg))then
+    i_undefg=int(undefg)
+    r_undefg=undefg
+  else
+    i_undefg=-999
+    r_undefg=-999.0
+  end if
+
+  if(present(undefg))then
+     if(present(undefgc))then
+        undefgcflag=undefgc(1:1)
+     else
+        undefgcflag="i"
+     end if
+  end if
+
+  if(present(stdopt))then
+     stderr=stdopt
+  else
+     stderr=.false.
+  end if
+
+  if(present(axis))then
+     ax_flag=axis(1:2)
+  else
+     ax_flag='xy'
+  end if
+
+!-- ΰ򥯥ꥢƤ뤫ǧ ---
+!-- ϹԤʤ.
+
+!  call search_region_1d( (/x(1),x(nx)/), (/y(1),y(ny)/), (/xc,yc/), r, nr,  &
+!  &                      stdopt=stderr, axis=ax_flag(1:2) )
+
+!--  v  undef ͤƤ.
+!  do j=1,nt
+!     do i=1,nrr
+!        v(i,j)=r_undef
+!     end do
+!  end do
+
+!-- (1) ---
+  if(ax_flag(1:2)=='xy')then
+     do j=1,nt
+        do i=1,nr
+           call rt_2_xy( r(i), theta(j), point(i,j,1), point(i,j,2) )
+           point(i,j,1)=xc+point(i,j,1)
+           point(i,j,2)=yc+point(i,j,2)
+        end do
+     end do
+  else
+     do j=1,nt
+        do i=1,nr
+           if(r(i)/=0.0)then
+              call rt2ll( r(i), theta(j), xc, yc, point(i,j,1), point(i,j,2) )
+           else
+              point(i,j,1)=xc
+              point(i,j,2)=yc
+           end if
+        end do
+     end do
+  end if
+
+!-- (2) ---
+  do j=1,nt
+     do i=1,nr
+        call interpo_search_2d( x, y, point(i,j,1), point(i,j,2),  &
+      &                         ip(i,j,1), ip(i,j,2), undeff=i_undef,  &
+  &                             stdopt=stderr )
+     end do
+  end do
+
+!-- (3) ---
+  do j=1,nt
+     do i=1,nr
+        if(ip(i,j,1)/=i_undef.and.ip(i,j,2)/=i_undef.and.  &
+  &        ip(i,j,1)/=nx.and.ip(i,j,2)/=ny)then
+           tmpx(1)=x(ip(i,j,1))
+           tmpx(2)=x(ip(i,j,1)+1)
+           tmpy(1)=y(ip(i,j,2))
+           tmpy(2)=y(ip(i,j,2)+1)
+           tmpz(1,1)=u(ip(i,j,1),ip(i,j,2))
+           tmpz(2,1)=u(ip(i,j,1)+1,ip(i,j,2))
+           tmpz(1,2)=u(ip(i,j,1),ip(i,j,2)+1)
+           tmpz(2,2)=u(ip(i,j,1)+1,ip(i,j,2)+1)
+           inter(1)=point(i,j,1)
+           inter(2)=point(i,j,2)
+
+           if(present(undefg))then
+              ucf=undef_checker_2d( tmpz, undefg )
+              if(ucf.eqv..false.)then
+                 call interpolation_2d( tmpx, tmpy, tmpz, inter, work(i,j) )
+              else
+                 work(i,j)=r_undefg
+                 undefgc_check(i)=.false.
+              end if
+           else
+              call interpolation_2d( tmpx, tmpy, tmpz, inter, work(i,j) )
+           end if
+        else
+           work(i,j)=r_undef
+        end if
+     end do
+  end do
+
+  do j=1,nt
+     do i=1,nr
+        v(i,j)=work(i,j)
+     end do
+  end do
+
+end subroutine tangent_conv_scal
+
+!--------------------------------------------------------------
+!--------------------------------------------------------------
 subroutine tangent_mean_scal( x, y, xc, yc, u, r, theta, v, undef,  &
-  &                           undefg, undefgc )
+  &                           undefg, undefgc, stdopt, axis )
   ! Ǥդʪ̤濴ʿѤ롼
   ! Υ롼®ʿѤˤѤ뤳ȤϤǤʤ.
   ! ʿѤԤݤˤ, ̤Υ롼, tangent_mean_vec λѤɬ.
@@ -36,13 +221,13 @@ subroutine tangent_mean_scal( x, y, xc, yc, u, r, theta, v, undef,  &
   use statistics
   use Geometry
   implicit none
-  real, intent(in) :: x(:)  ! ǥȺɸϤǤ x ɸ
-  real, intent(in) :: y(:)  ! ǥȺɸϤǤ y ɸ
-  real, intent(in) :: u(size(x),size(y))  ! ǥȺɸϤǤʿѲ
-  real, intent(in) :: xc  ! ʿѤݤ濴 x ʬ.
-  real, intent(in) :: yc  ! ʿѤݤ濴 y ʬ.
-  real, intent(in) :: r(:)  ! ʿѲȤưκɸ(xc ͤ).
-  real, intent(in) :: theta(:)  ! ʿѲȤκɸ [rad].
+  real, intent(in) :: x(:)  ! ɸϤǤʬ [m or rad]
+  real, intent(in) :: y(:)  ! ɸϤǤʬ [m or rad]
+  real, intent(in) :: u(size(x),size(y))  ! ɸϤǤʿѲ
+  real, intent(in) :: xc  ! ʿѤݤ濴 x ʬ. [m or rad]
+  real, intent(in) :: yc  ! ʿѤݤ濴 y ʬ. [m or rad]
+  real, intent(in) :: r(:)  ! (xc, yc) 濴Ȥ˺ɸưºɸ [m].
+  real, intent(in) :: theta(:)  ! (xc, yc) 濴Ȥ˺ɸƱ̳Ѻɸ [rad].
   real, intent(inout) :: v(size(r))  ! ʿѲ u .
   real, intent(in), optional :: undef   ! ΰ賰
   real, intent(in), optional :: undefg  ! ʻ˷»̤
@@ -50,96 +235,77 @@ subroutine tangent_mean_scal( x, y, xc, yc, u, r, theta, v, undef,  &
                 ! "inc" = γʻ򻲾ͤȤޤΤʿ˽Ʒ׻.
                 ! "err" = γʻ򻲾ͤȤޤʿ˴ޤ, ʿͤΤΤ̤ȤƷ׻. ξ, ̤ͤ undefg Ȥʤ.
                 ! ǥեȤ "inc".
-  integer :: i, j, nx, ny, nr, nrr, nt
+  logical, intent(in), optional :: stdopt  ! õϰϤĤʤݤɸϤɽʤ褦ˤ.
+                                           ! default Ǥ .false. (ɽ)
+  character(2), intent(in), optional :: axis  ! x, y κɸ
+                                           ! 'xy' = ǥȺɸ [m]
+                                           ! 'll' = ̰ٷٺɸ [rad]
+                                           ! ǥեȤ 'xy'.
+  integer :: i, nx, ny, nr, nt, i_undef, i_undefg
+  real :: r_undef, r_undefg
   real :: work(size(r),size(theta))
-  real :: point(size(r),size(theta),2)
-  integer :: ip(size(r),size(theta),2)
-  real :: tmpx(2), tmpy(2), tmpz(2,2), inter(2)
-  character(1) :: undefgcflag
+  character(3) :: undefgcflag
+  character(2) :: ax_flag
   logical, dimension(size(r)) :: undefgc_check
-  logical :: ucf
+  logical :: stderr
 
   nx=size(x)
   ny=size(y)
-  nrr=size(r)
+  nr=size(r)
   nt=size(theta)
 
   undefgc_check(:)=.true.
 
+  if(present(undef))then
+    i_undef=int(undef)
+    r_undef=undef
+  else
+    i_undef=-999
+    r_undef=-999.0
+  end if
+
+  if(present(undefg))then
+    i_undefg=int(undefg)
+    r_undefg=undefg
+  else
+    i_undefg=-999
+    r_undefg=-999.0
+  end if
+
   if(present(undefg))then
      if(present(undefgc))then
-        undefgcflag=undefgc(1:1)
+        undefgcflag=undefgc(1:3)
      else
-        undefgcflag="i"
+        undefgcflag="inc"
      end if
   end if
 
-!-- ΰ򥯥ꥢƤ뤫ǧ ---
+  if(present(stdopt))then
+     stderr=stdopt
+  else
+     stderr=.false.
+  end if
 
-  call search_region_1d( (/x(1),x(nx)/), (/y(1),y(ny)/), (/xc,yc/), r, nr )
+  if(present(axis))then
+     ax_flag=axis(1:2)
+  else
+     ax_flag='xy'
+  end if
 
-!--  v  undef ͤƤ.
-  do i=1,nrr
-     if(present(undef))then
-        v(i)=undef
-     else
-        v(i)=0.0
-     end if
-  end do
+!-- (1) - (3)
 
-!-- (1) ---
-  do j=1,nt
-     do i=1,nr
-        call rt_2_xy( r(i), theta(j), point(i,j,1), point(i,j,2) )
-        point(i,j,1)=xc+point(i,j,1)
-        point(i,j,2)=yc+point(i,j,2)
-     end do
-  end do
-
-!-- (2) ---
-  do j=1,nt
-     do i=1,nr
-        call interpo_search_2d( x, y, point(i,j,1), point(i,j,2),  &
-      &                         ip(i,j,1), ip(i,j,2) )
-     end do
-  end do
-
-!-- (3) ---
-  do j=1,nt
-     do i=1,nr
-        tmpx(1)=x(ip(i,j,1))
-        tmpx(2)=x(ip(i,j,1)+1)
-        tmpy(1)=y(ip(i,j,2))
-        tmpy(2)=y(ip(i,j,2)+1)
-        tmpz(1,1)=u(ip(i,j,1),ip(i,j,2))
-        tmpz(2,1)=u(ip(i,j,1)+1,ip(i,j,2))
-        tmpz(1,2)=u(ip(i,j,1),ip(i,j,2)+1)
-        tmpz(2,2)=u(ip(i,j,1)+1,ip(i,j,2)+1)
-        inter(1)=point(i,j,1)
-        inter(2)=point(i,j,2)
-
-        if(present(undefg))then
-           ucf=undef_checker_2d( tmpz, undefg )
-           if(ucf.eqv..false.)then
-              call interpolation_2d( tmpx, tmpy, tmpz, inter, work(i,j) )
-           else
-              work(i,j)=undefg
-              undefgc_check(i)=.false.
-           end if
-        else
-           call interpolation_2d( tmpx, tmpy, tmpz, inter, work(i,j) )
-        end if
-     end do
-  end do
+  call tangent_conv_scal( x, y, xc, yc, u, r, theta, work, undef=r_undef,  &
+  &                       undefg=r_undefg, undefgc=undefgcflag(1:3),  &
+  &                       stdopt=stderr, axis=ax_flag(1:2) )
 
 !-- (4) ---
   if(present(undefg))then
      if(undefgcflag(1:1)=='i')then
-        do i=2,nr
+        do i=1,nr
            call Mean_1d( work(i,:), v(i), error=undefg )
         end do
      else
-        do i=2,nr
+        do i=1,nr
            if(undefgc_check(i).eqv..true.)then
               call Mean_1d( work(i,:), v(i) )
            else
@@ -148,20 +314,18 @@ subroutine tangent_mean_scal( x, y, xc, yc, u, r, theta, v, undef,  &
         end do
      end if
   else
-     do i=2,nr
+     do i=1,nr
         call Mean_1d( work(i,:), v(i) )
      end do
   end if
 
-  v(1)=work(1,1)
-
 end subroutine tangent_mean_scal
 
 !--------------------------------------------------------------
 !--------------------------------------------------------------
 
 subroutine tangent_mean_anom_scal( x, y, xc, yc, u, r, theta, v, undef,  &
-  &                                undefg, undefgc )
+  &                                undefg, undefgc, stdopt, axis )
   ! Ǥդʪ̤濴ʿѤ, ΥΥޥ꡼׻롼
   ! ¤Ȥ, |x(1)-xc|, |xc-x(nx)|, |y(1)-yc|, |yc-y(ny)| > r. 
   ! ʳξ, r ͿΥΰ賰ϰϤˤĤƤ
@@ -185,13 +349,13 @@ subroutine tangent_mean_anom_scal( x, y, xc, yc, u, r, theta, v, undef,  &
   use statistics
   use Geometry
   implicit none
-  real, intent(in) :: x(:)  ! ǥȺɸϤǤ x ɸ
-  real, intent(in) :: y(:)  ! ǥȺɸϤǤ y ɸ
-  real, intent(in) :: u(size(x),size(y))  ! ǥȺɸϤǤʿѲ
-  real, intent(in) :: xc  ! ʿѤݤ濴 x ʬ.
-  real, intent(in) :: yc  ! ʿѤݤ濴 y ʬ.
-  real, intent(in) :: r(:)  ! ʿѲȤưκɸ(xc ͤ).
-  real, intent(in) :: theta(:)  ! ʿѲȤκɸ [rad].
+  real, intent(in) :: x(:)  ! ɸϤǤʬ [m or rad]
+  real, intent(in) :: y(:)  ! ɸϤǤʬ [m or rad]
+  real, intent(in) :: u(size(x),size(y))  ! ɸϤǤʿѲ
+  real, intent(in) :: xc  ! ʿѤݤ濴 x ʬ. [m or rad]
+  real, intent(in) :: yc  ! ʿѤݤ濴 y ʬ. [m or rad]
+  real, intent(in) :: r(:)  ! (xc, yc) 濴Ȥ˺ɸưºɸ [m].
+  real, intent(in) :: theta(:)  ! (xc, yc) 濴Ȥ˺ɸƱ̳Ѻɸ [rad].
   real, intent(inout) :: v(size(r),size(theta))  ! ʿѲ u ΥΥޥ꡼.
   real, intent(in), optional :: undef  ! ΰ賰
   real, intent(in), optional :: undefg  ! ʻ˷»̤
@@ -199,98 +363,77 @@ subroutine tangent_mean_anom_scal( x, y, xc, yc, u, r, theta, v, undef,  &
                 ! "inc" = γʻ򻲾ͤȤޤΤʿ˽Ʒ׻.
                 ! "err" = γʻ򻲾ͤȤޤʿ˴ޤ, ʿͤΤΤ̤ȤƷ׻. ξ, ̤ͤ undefg Ȥʤ.
                 ! ǥեȤ "inc".
-  integer :: i, j, nx, ny, nr, nrr, nt
+  logical, intent(in), optional :: stdopt  ! õϰϤĤʤݤɸϤɽʤ褦ˤ.
+                                           ! default Ǥ .false. (ɽ)
+  character(2), intent(in), optional :: axis  ! x, y κɸ
+                                           ! 'xy' = ǥȺɸ [m]
+                                           ! 'll' = ̰ٷٺɸ [rad]
+                                           ! ǥեȤ 'xy'.
+  integer :: i, j, nx, ny, nr, nt, i_undef, i_undefg
+  real :: r_undef, r_undefg
   real :: work(size(r),size(theta))
-  real :: point(size(r),size(theta),2)
-  integer :: ip(size(r),size(theta),2)
-  real :: tmpx(2), tmpy(2), tmpz(2,2), inter(2)
-  character(1) :: undefgcflag
+  character(3) :: undefgcflag
+  character(2) :: ax_flag
   logical, dimension(size(r)) :: undefgc_check
-  logical :: ucf
+  logical :: stderr
 
   nx=size(x)
   ny=size(y)
-  nrr=size(r)
+  nr=size(r)
   nt=size(theta)
 
   undefgc_check(:)=.true.
 
+  if(present(undef))then
+    i_undef=int(undef)
+    r_undef=undef
+  else
+    i_undef=-999
+    r_undef=-999.0
+  end if
+
+  if(present(undefg))then
+    i_undefg=int(undefg)
+    r_undefg=undefg
+  else
+    i_undefg=-999
+    r_undefg=-999.0
+  end if
+
   if(present(undefg))then
      if(present(undefgc))then
-        undefgcflag=undefgc(1:1)
+        undefgcflag=undefgc(1:3)
      else
-        undefgcflag="i"
+        undefgcflag="inc"
      end if
   end if
 
-!-- ΰ򥯥ꥢƤ뤫ǧ ---
+  if(present(stdopt))then
+     stderr=stdopt
+  else
+     stderr=.false.
+  end if
 
-  call search_region_1d( (/x(1),x(nx)/), (/y(1),y(ny)/), (/xc,yc/), r, nr )
+  if(present(axis))then
+     ax_flag=axis(1:2)
+  else
+     ax_flag='xy'
+  end if
 
-!--  v  undef ͤƤ.
-  do j=1,nt
-     do i=1,nrr
-        if(present(undef))then
-           v(i,j)=undef
-        else
-           v(i,j)=0.0
-        end if
-     end do
-  end do
+!-- (1) - (3) ---
 
-!-- (1) ---
-  do j=1,nt
-     do i=1,nr
-        call rt_2_xy( r(i), theta(j), point(i,j,1), point(i,j,2) )
-        point(i,j,1)=xc+point(i,j,1)
-        point(i,j,2)=yc+point(i,j,2)
-     end do
-  end do
-
-!-- (2) ---
-  do j=1,nt
-     do i=1,nr
-        call interpo_search_2d( x, y, point(i,j,1), point(i,j,2),  &
-      &                         ip(i,j,1), ip(i,j,2) )
-     end do
-  end do
-
-!-- (3) ---
-  do j=1,nt
-     do i=1,nr
-        tmpx(1)=x(ip(i,j,1))
-        tmpx(2)=x(ip(i,j,1)+1)
-        tmpy(1)=y(ip(i,j,2))
-        tmpy(2)=y(ip(i,j,2)+1)
-        tmpz(1,1)=u(ip(i,j,1),ip(i,j,2))
-        tmpz(2,1)=u(ip(i,j,1)+1,ip(i,j,2))
-        tmpz(1,2)=u(ip(i,j,1),ip(i,j,2)+1)
-        tmpz(2,2)=u(ip(i,j,1)+1,ip(i,j,2)+1)
-        inter(1)=point(i,j,1)
-        inter(2)=point(i,j,2)
-
-        if(present(undefg))then
-           ucf=undef_checker_2d( tmpz, undefg )
-           if(ucf.eqv..false.)then
-              call interpolation_2d( tmpx, tmpy, tmpz, inter, work(i,j) )
-           else
-              work(i,j)=undefg
-              undefgc_check(i)=.false.
-           end if
-        else
-           call interpolation_2d( tmpx, tmpy, tmpz, inter, work(i,j) )
-        end if
-     end do
-  end do
+  call tangent_conv_scal( x, y, xc, yc, u, r, theta, work, undef=r_undef,  &
+  &                       undefg=r_undefg, undefgc=undefgcflag(1:3),  &
+  &                       stdopt=stderr, axis=ax_flag(1:2) )
 
 !-- (4) ---
   if(present(undefg))then
      if(undefgcflag(1:1)=='i')then
-        do i=2,nr
+        do i=1,nr
            call Anomaly_1d( work(i,:), v(i,:), error=undefg )
         end do
      else
-        do i=2,nr
+        do i=1,nr
            if(undefgc_check(i).eqv..true.)then
               call Anomaly_1d( work(i,:), v(i,:) )
            else
@@ -301,19 +444,18 @@ subroutine tangent_mean_anom_scal( x, y, xc, yc, u, r, theta, v, undef,  &
         end do
      end if
   else
-     do i=2,nr
+     do i=1,nr
         call Anomaly_1d( work(i,:), v(i,:) )
      end do
   end if
 
-  v(1,:)=work(1,1)
-
 end subroutine tangent_mean_anom_scal
 
 !--------------------------------------------------------------
 !--------------------------------------------------------------
 subroutine tangent_mean_anom_scal_Cart( x, y, xc, yc, scal, r, theta,  &
-  &                                     scal_anom, undef, undefg, undefgc )
+  &                                     scal_anom, undef, undefg, undefgc,  &
+  &                                     stdopt )
   ! 濴Υޥ׻, ǥȺɸϤ᤹.
   ! ʿѥ롼Ѥʪ̤ʿѤ,  1 ǡݤƤ.
   ! Ʊ, ǥȷϤǤʪ̤αɸϤǤ radial ֤.
@@ -338,10 +480,13 @@ subroutine tangent_mean_anom_scal_Cart( x, y, xc, yc, scal, r, theta,  &
   character(3), intent(in), optional :: undefgc  ! undefg ν
                 ! "inc" = γʻ򻲾ͤȤޤΤʿ˽Ʒ׻.
                 ! "err" = γʻ򻲾ͤȤޤʿ˴ޤ, ʿͤΤΤ̤ȤƷ׻. ξ, ̤ͤ undefg Ȥʤ.
+  logical, intent(in), optional :: stdopt  ! õϰϤĤʤݤɸϤɽʤ褦ˤ.
+                                           ! default Ǥ .false. (ɽ)
   integer :: j, k, nx, ny, nr, nt, itmpr
   real :: tmp(size(r))
   real :: tmpr, tmp_anom, undeff
   character(3) :: undefgcflag
+  logical :: stderr
 
   if(present(undef))then
      undeff=undef
@@ -349,6 +494,12 @@ subroutine tangent_mean_anom_scal_Cart( x, y, xc, yc, scal, r, theta,  &
      undeff=999.0
   end if
 
+  if(present(stdopt))then
+     stderr=stdopt
+  else
+     stderr=.false.
+  end if
+
   nx=size(x)
   ny=size(y)
   nr=size(r)
@@ -364,9 +515,11 @@ subroutine tangent_mean_anom_scal_Cart( x, y, xc, yc, scal, r, theta,  &
 
   if(present(undefg))then
      call tangent_mean_scal( x, y, xc, yc, scal, r, theta, tmp,  &
-  &                    undef=undeff, undefg=undefg, undefgc=undefgcflag(1:3) )
+  &                    undef=undeff, undefg=undefg, undefgc=undefgcflag(1:3),  &
+  &                    stdopt=stderr )
   else
-     call tangent_mean_scal( x, y, xc, yc, scal, r, theta, tmp, undef=undeff )
+     call tangent_mean_scal( x, y, xc, yc, scal, r, theta, tmp, undef=undeff,  &
+  &                          stdopt=stderr )
   end if
 
 !-- ʿͤޤ, ͤƥΥޥ.
@@ -375,7 +528,7 @@ subroutine tangent_mean_anom_scal_Cart( x, y, xc, yc, scal, r, theta,  &
         do k=1,ny
            do j=1,nx
               tmpr=sqrt((x(j)-xc)**2+(y(k)-yc)**2)
-              call interpo_search_1d( r, tmpr, itmpr )
+              call interpo_search_1d( r, tmpr, itmpr, stdopt=stderr )
               if(nr>itmpr)then
                  if(tmp(itmpr)/=undefg.and.tmp(itmpr+1)/=undefg)then
                     call interpolation_1d( (/r(itmpr), r(itmpr+1)/),  &
@@ -393,7 +546,7 @@ subroutine tangent_mean_anom_scal_Cart( x, y, xc, yc, scal, r, theta,  &
         do k=1,ny
            do j=1,nx
               tmpr=sqrt((x(j)-xc)**2+(y(k)-yc)**2)
-              call interpo_search_1d( r, tmpr, itmpr )
+              call interpo_search_1d( r, tmpr, itmpr, stdopt=stderr )
               if(nr>itmpr)then
                  if(tmp(itmpr)/=undefg.and.tmp(itmpr+1)/=undefg.and.  &
   &                 scal(j,k)/=undefg)then
@@ -413,7 +566,7 @@ subroutine tangent_mean_anom_scal_Cart( x, y, xc, yc, scal, r, theta,  &
      do k=1,ny
         do j=1,nx
            tmpr=sqrt((x(j)-xc)**2+(y(k)-yc)**2)
-           call interpo_search_1d( r, tmpr, itmpr )
+           call interpo_search_1d( r, tmpr, itmpr, stdopt=stderr )
            if(nr>itmpr)then
               call interpolation_1d( (/r(itmpr), r(itmpr+1)/),  &
   &                               (/tmp(itmpr), tmp(itmpr+1)/), tmpr, tmp_anom )
@@ -431,7 +584,7 @@ end subroutine tangent_mean_anom_scal_Cart
 !--------------------------------------------------------------
 
 subroutine tangent_mean_vec( charc, x, y, xc, yc, u1, u2, r, theta, v,  &
-  &                          undef, undefg, undefgc )
+  &                          undef, undefg, undefgc, stdopt )
   ! Ǥդʪ̤濴ʿѤ롼
   ! ®ʿ.
   ! ¤Ȥ, |x(1)-xc|, |xc-x(nx)|, |y(1)-yc|, |yc-y(ny)| > r.
@@ -474,13 +627,22 @@ subroutine tangent_mean_vec( charc, x, y, xc, yc, u1, u2, r, theta, v,  &
   character(3), intent(in), optional :: undefgc  ! undefg ν
                 ! "inc" = γʻ򻲾ͤȤޤΤʿ˽Ʒ׻.
                 ! "err" = γʻ򻲾ͤȤޤʿ˴ޤ, ʿͤΤΤ̤ȤƷ׻. ξ, ̤ͤ undefg Ȥʤ.
+  logical, intent(in), optional :: stdopt  ! õϰϤĤʤݤɸϤɽʤ褦ˤ.
+                                           ! default Ǥ .false. (ɽ)
   integer :: i, j, nx, ny, z_count
   real, dimension(size(x),size(y)) :: posx, posy, abpos, vecz
+  logical :: stderr
 
   nx=size(x)
   ny=size(y)
   z_count=0
 
+  if(present(stdopt))then
+     stderr=stdopt
+  else
+     stderr=.false.
+  end if
+
 !-- ޤ, charc ˹碌, ʿ٥ȥư¡Ѵ.
 !-- Ѵ, ͤϥ顼ͤȤɾΤ,
 !-- tangent_mean_scal ꤲ.
@@ -542,16 +704,17 @@ subroutine tangent_mean_vec( charc, x, y, xc, yc, u1, u2, r, theta, v,  &
      if(present(undefg))then
         call tangent_mean_scal( x, y, xc, yc, vecz, r, theta, v,  &
   &                             undef=undef, undefg=undefg,  &
-  &                             undefgc=trim(undefgc) )
+  &                             undefgc=trim(undefgc), stdopt=stderr )
      else
         call tangent_mean_scal( x, y, xc, yc, vecz, r, theta, v,  &
-  &                             undef=undef )
+  &                             undef=undef, stdopt=stderr )
      end if
   else if(present(undefg))then
      call tangent_mean_scal( x, y, xc, yc, vecz, r, theta, v,  &
-  &                          undefg=undefg, undefgc=trim(undefgc) )
+  &                          undefg=undefg, undefgc=trim(undefgc),  &
+  &                          stdopt=stderr )
   else
-     call tangent_mean_scal( x, y, xc, yc, vecz, r, theta, v )
+     call tangent_mean_scal( x, y, xc, yc, vecz, r, theta, v, stdopt=stderr )
   end if
 
 end subroutine tangent_mean_vec
@@ -560,7 +723,7 @@ end subroutine tangent_mean_vec
 !--------------------------------------------------------------
 
 subroutine tangent_mean_anom_vec( charc, x, y, xc, yc, u1, u2, r, theta, v,  &
-  &                               undef, undefg, undefgc )
+  &                               undef, undefg, undefgc, stdopt )
   ! Ǥդʪ̤濴ʿѥΥޥ׻롼
   ! ®ʿ.
   ! ¤Ȥ, |x(1)-xc|, |xc-x(nx)|, |y(1)-yc|, |yc-y(ny)| > r. 
@@ -603,13 +766,22 @@ subroutine tangent_mean_anom_vec( charc, x, y, xc, yc, u1, u2, r, theta, v,  &
   character(3), intent(in), optional :: undefgc  ! undefg ν
                 ! "inc" = γʻ򻲾ͤȤޤΤʿ˽Ʒ׻.
                 ! "err" = γʻ򻲾ͤȤޤʿ˴ޤ, ʿͤΤΤ̤ȤƷ׻. ξ, ̤ͤ undefg Ȥʤ.
+  logical, intent(in), optional :: stdopt  ! õϰϤĤʤݤɸϤɽʤ褦ˤ.
+                                           ! default Ǥ .false. (ɽ)
   integer :: i, j, nx, ny, z_count
   real, dimension(size(x),size(y)) :: posx, posy, abpos, vecz
+  logical :: stderr
 
   nx=size(x)
   ny=size(y)
   z_count=0
 
+  if(present(stdopt))then
+     stderr=stdopt
+  else
+     stderr=.false.
+  end if
+
 !-- ޤ, charc ˹碌, ʿ٥ȥư¡Ѵ.
 !-- Ѵ, ͤϥ顼ͤȤɾΤ,
 !-- tangent_mean_scal ꤲ.
@@ -671,16 +843,18 @@ subroutine tangent_mean_anom_vec( charc, x, y, xc, yc, u1, u2, r, theta, v,  &
      if(present(undefg))then
         call tangent_mean_anom_scal( x, y, xc, yc, vecz, r, theta, v,  &
   &                                  undef=undef, undefg=undefg,  &
-  &                                  undefgc=trim(undefgc) )
+  &                                  undefgc=trim(undefgc), stdopt=stderr )
      else
         call tangent_mean_anom_scal( x, y, xc, yc, vecz, r, theta, v,  &
-  &                                  undef=undef )
+  &                                  undef=undef, stdopt=stderr )
      end if
   else if(present(undefg))then
      call tangent_mean_anom_scal( x, y, xc, yc, vecz, r, theta, v,  &
-  &                               undefg=undefg, undefgc=trim(undefgc) )
+  &                               undefg=undefg, undefgc=trim(undefgc),  &
+  &                               stdopt=stderr )
   else
-     call tangent_mean_anom_scal( x, y, xc, yc, vecz, r, theta, v )
+     call tangent_mean_anom_scal( x, y, xc, yc, vecz, r, theta, v,  &
+  &                               stdopt=stderr )
   end if
 
 end subroutine tangent_mean_anom_vec
@@ -1067,11 +1241,12 @@ end subroutine
 !--------------------------------------------------------------
 !--------------------------------------------------------------
 
-subroutine hydro_grad_eqb( r, z, coril, v, pres_s, rho_s, pres, rho, error )
+subroutine hydro_grad_eqb( r, z, coril, v, pres_s, rho_s, pres, rho, error, dl )
 !  ǥ󥰤ȼоήϳءʿվη׻.
   use Thermo_Const
   use Phys_Const
   use algebra
+  use stdio
   use Derivation
   implicit none
   real, intent(in) :: r(:)  ! ưºɸ [m]
@@ -1084,6 +1259,7 @@ subroutine hydro_grad_eqb( r, z, coril, v, pres_s, rho_s, pres, rho, error )
                     ! default = 1.0e-5
   real, intent(inout) :: pres(size(r),size(z))  ! ʿվε [Pa]
   real, intent(inout) :: rho(size(r),size(z))  ! ʿվ̩ [kg/m^3]
+  integer, intent(in), optional :: dl  ! ǥХå٥
   real :: old_pres(size(r),size(z)), old_rho(size(r),size(z))
   integer :: nr, nz
   integer :: i, j
@@ -1117,17 +1293,18 @@ subroutine hydro_grad_eqb( r, z, coril, v, pres_s, rho_s, pres, rho, error )
   do while(err>=err_max)
      err=0.0
 !-- ʿդ鰵Ͼ׻
+!$omp parallel default(shared)
+!$omp do schedule(dynamic) private(j)
      do j=1,nz
         call grad_wind_pres( r, coril(:,j), v(:,j), old_rho(:,j), r(nr), old_pres(nr,j), pres(:,j) )
      end do
+!$omp end do
+!$omp end parallel
 
 !-- ϳʿդ̩پ
      do i=1,nr
         call grad_1d( z, pres(i,:), rho(i,:) )
         do j=1,nz
-if(i==1)then
-write(*,*) "#### pres", pres(i,j), rho(i,j)
-end if
            rho(i,j)=-rho(i,j)/g  ! ϳؤμ, dp/dz=-g*rho ǤΤ
         end do
      end do
@@ -1154,6 +1331,13 @@ end if
 
   end do
 
+  if(present(dl))then
+     do j=1,nz
+        call debug_flag_r( dl, 'typhoon_analy', 'hydro_grad_eqb (pres)',  &
+  &                        pres(1,j), 'Pa' )
+     end do
+  end if
+
 end subroutine
 
 !--------------------------------------------------------------
@@ -1202,7 +1386,8 @@ end subroutine
 !--------------------------------------------------------------
 !--------------------------------------------------------------
 
-subroutine DC_Braun( x, y, fg, pres, search_dis, var_dis, center, undef )
+subroutine DC_Braun( x, y, fg, pres, search_dis, var_dis, center, undef,  &
+  &                  stdopt )
 ! Braun (2002) ˡ濴ꤹ.
   use Math_Const
   use Max_Min
@@ -1223,13 +1408,16 @@ subroutine DC_Braun( x, y, fg, pres, search_dis, var_dis, center, undef )
   real, intent(in), optional :: undef  ! ̤ͤ, ̤.
                              ! ܥ롼Ǥ, ̤ͤ, 
                              ! γʻΤк׻˻Ѥʤ.
+  logical, intent(in), optional :: stdopt  ! õϰϤĤʤݤɸϤɽʤ褦ˤ.
+                                           ! default Ǥ .false. (ɽ)
 
   integer :: i, j, ix, jy, nx, ny, nr, nt, nxgmin, nxgmax, nygmin, nygmax
-  integer :: ompnum, tmp_o_num, is_dis
-  real :: dr, dtheta, xc, yc, undeff, tmpmin, tmp_anom, tmp_counter
+  integer :: ompnum, tmp_o_num
+  real :: dr, dtheta, undeff, tmpmin, tmp_anom, tmp_counter
   real, allocatable, dimension(:) :: rad, theta
   real, allocatable, dimension(:,:) :: anom_check
   real, allocatable, dimension(:,:,:) :: apres
+  logical :: stderr
 
 !-- OpenMP ؿ
 !$ integer :: OMP_GET_THREAD_NUM, OMP_GET_MAX_THREADS
@@ -1243,15 +1431,23 @@ subroutine DC_Braun( x, y, fg, pres, search_dis, var_dis, center, undef )
      undeff=-999.0
   end if
 
+  if(present(stdopt))then
+     stderr=stdopt
+  else
+     stderr=.false.
+  end if
+
 !-- ʻϰϤ
 
   call interpo_search_2d( x, y, x(fg(1))-0.5*search_dis,  &
   &                             y(fg(2))-0.5*search_dis,  &
-  &                       nxgmin, nygmin, undeff=int(undeff) )
+  &                       nxgmin, nygmin, undeff=int(undeff),  &
+  &                       stdopt=stderr )
 
   call interpo_search_2d( x, y, x(fg(1))+0.5*search_dis,  &
   &                             y(fg(2))+0.5*search_dis,  &
-  &                       nxgmax, nygmax, undeff=int(undeff) )
+  &                       nxgmax, nygmax, undeff=int(undeff),  &
+  &                       stdopt=stderr )
 
   if(nxgmin==int(undeff))then  ! ΰ賰Ȥξν
      nxgmin=1
@@ -1322,7 +1518,8 @@ subroutine DC_Braun( x, y, fg, pres, search_dis, var_dis, center, undef )
 
            call tangent_mean_anom_scal_Cart( x, y, x(i), y(j), pres, rad, theta,  &
   &                                          apres(:,:,tmp_o_num), undef=undeff,  &
-  &                                          undefg=undeff, undefgc='inc' )
+  &                                          undefg=undeff, undefgc='inc',  &
+  &                                          stdopt=stderr )
 
            tmp_anom=0.0
 
@@ -1360,7 +1557,7 @@ end subroutine DC_Braun
 !  ʲ, private 롼
 !--------------------------------------------------------------
 
-subroutine search_region_1d( x, y, c, r, nr )
+subroutine search_region_1d( x, y, c, r, nr, stdopt )
 ! ʿѲǽȾ¤׻롼
   use Statistics
   implicit none
@@ -1369,45 +1566,62 @@ subroutine search_region_1d( x, y, c, r, nr )
   real, intent(in) :: c(2)  ! 濴ΰֺɸ (x,y) [m]
   real, intent(in) :: r(:)  ! ưΰֺɸ [m]
   integer, intent(inout) :: nr  ! ʿѲǽȾ¤ֹ (r(nr) ǽȾ)
+  logical, intent(in), optional :: stdopt  ! õϰϤĤʤݤɸϤɽʤ褦ˤ.
+                                           ! default Ǥ .false. (ɽ)
   integer :: nrr, tmp_nr
   real :: xc, yc
+  logical :: stderr
 
   nrr=size(r)
   xc=c(1)
   yc=c(2)
-
   nr=nrr
+
+  if(present(stdopt))then
+     stderr=stdopt
+  else
+     stderr=.false.
+  end if
+
   if(abs(x(1)-xc) < r(nrr))then
-     write(*,*) "typhoon_analy WARNING :"
-     write(*,*) "|x(1)-xc| >= rmax. "
-     write(*,*) "undef value is substituted out of region."
-     call interpo_search_1d( r, abs(x(1)-xc), tmp_nr )
+     if(stderr.eqv..false.)then
+        write(*,*) "typhoon_analy WARNING :"
+        write(*,*) "|x(1)-xc| >= rmax. "
+        write(*,*) "undef value is substituted out of region."
+     end if
+     call interpo_search_1d( r, abs(x(1)-xc), tmp_nr, stdopt=stderr )
      nr=tmp_nr+1  ! interpo_search  abs ͤ꾮 r ֹ椬뤿.
                   ! ʲƱͳ
   else
      if(abs(x(2)-xc) < r(nrr))then
-     write(*,*) "typhoon_analy WARNING :"
-        write(*,*) "|x(nx)-xc| >= rmax. "
-        write(*,*) "undef value is substituted out of region."
-        call interpo_search_1d( r, abs(x(2)-xc), tmp_nr )
+        if(stderr.eqv..false.)then
+           write(*,*) "typhoon_analy WARNING :"
+           write(*,*) "|x(nx)-xc| >= rmax. "
+           write(*,*) "undef value is substituted out of region."
+        end if
+        call interpo_search_1d( r, abs(x(2)-xc), tmp_nr, stdopt=stderr )
         if(tmp_nr+1<nr)then
            nr=tmp_nr+1
         end if
      else
         if(abs(y(1)-yc) < r(nrr))then
-           write(*,*) "typhoon_analy WARNING :"
-           write(*,*) "|y(1)-yc| >= rmax. "
-           write(*,*) "undef value is substituted out of region."
-           call interpo_search_1d( r, abs(y(1)-yc), tmp_nr )
+           if(stderr.eqv..false.)then
+              write(*,*) "typhoon_analy WARNING :"
+              write(*,*) "|y(1)-yc| >= rmax. "
+              write(*,*) "undef value is substituted out of region."
+           end if
+           call interpo_search_1d( r, abs(y(1)-yc), tmp_nr, stdopt=stderr )
            if(tmp_nr+1<nr)then
               nr=tmp_nr+1
            end if
         else
            if(abs(y(2)-yc) < r(nrr))then
-              write(*,*) "typhoon_analy WARNING :"
-              write(*,*) "|y(ny)-yc| >= rmax. "
-              write(*,*) "undef value is substituted out of region."
-              call interpo_search_1d( r, abs(y(2)-yc), tmp_nr )
+              if(stderr.eqv..false.)then
+                 write(*,*) "typhoon_analy WARNING :"
+                 write(*,*) "|y(ny)-yc| >= rmax. "
+                 write(*,*) "undef value is substituted out of region."
+              end if
+              call interpo_search_1d( r, abs(y(2)-yc), tmp_nr, stdopt=stderr )
               if(tmp_nr+1<nr)then
                  nr=tmp_nr+1
               end if
