@@ -28,7 +28,7 @@ real function Lv( temp )
   implicit none
   real, intent(in) :: temp  !  [K]
 
-  call ptcheck( temp )
+  call ptcheck( temp, 'Lv' )
 
   Lv=2.50078e6*(ti0/temp)**(0.167+3.67e-4*temp)
 
@@ -42,7 +42,7 @@ real function Ls( temp )
   implicit none
   real, intent(in) :: temp !  [K]
 
-  call ptcheck( temp )
+  call ptcheck( temp, 'Ls' )
 
   Ls=2.834e6+100.0*(temp-ti0)
 
@@ -56,7 +56,7 @@ real function Lf( temp )
   implicit none
   real, intent(in) :: temp !  [K]
 
-  call ptcheck( temp )
+  call ptcheck( temp,'Lf' )
 
   Lf=3.34e5+2500.0*(temp-ti0)
 
@@ -71,7 +71,7 @@ real function nu_air( temp, pres )
   real, intent(in) :: temp !  [K]
   real, intent(in) :: pres !  [Pa]
 
-  call ptcheck( temp )
+  call ptcheck( temp, 'nu air' )
 
   nu_air=1.328e-5*(p00/pres)*(temp/ti0)**1.754
 
@@ -86,7 +86,7 @@ real function mu_air( temp, pres )
   real, intent(in) :: pres !  [Pa]
   real :: rho
 
-  call ptcheck( temp )
+  call ptcheck( temp, 'mu air' )
 
   rho=TP_2_rho( temp, pres )
 
@@ -103,7 +103,7 @@ real function Dv( temp, pres )
   real, intent(in) :: temp !  [K]
   real, intent(in) :: pres !  [Pa]
 
-  call ptcheck( temp )
+  call ptcheck( temp, 'Dv' )
 
   Dv=2.23e-5*(p00/pres)*(temp/ti0)**1.81
 
@@ -119,7 +119,7 @@ real function qvss( temp, pres )
   real :: eps
   real :: a, b, c, tmp
 
-  call ptcheck( temp )
+  call ptcheck( temp, 'qvss' )
 
   a=610.78
   b=17.269
@@ -141,7 +141,7 @@ real function qvsi( temp, pres )
   real :: eps
   real :: a, b, c, tmp
 
-  call ptcheck( temp )
+  call ptcheck( temp, 'qvsi' )
 
   a=610.78
   b=21.875
@@ -249,7 +249,7 @@ real function Knudsen( temp, pres )
   real, intent(in) :: temp   !  [k]
   real, intent(in) :: pres   !  [Pa]
 
-  call ptcheck( temp )
+  call ptcheck( temp, 'Knudsen' )
 
   Knudsen=MFP0*p00*temp/(tref*Raero*pres)
 
@@ -270,7 +270,7 @@ real function Daero( temp, pres )
   real, intent(in) :: pres   !  [Pa]
   real :: Tcl
 
-  call ptcheck( temp )
+  call ptcheck( temp, 'Daero' )
 
   Tcl=temp
   Daero=kB*Tcl*(1.0+Knudsen( temp, pres ))/(6.0*pi*Raero*mu_air( temp, pres ))
@@ -290,7 +290,7 @@ real function Naero( temp )
   implicit none
   real, intent(in) :: temp   !  [k]
 
-  call ptcheck( temp )
+  call ptcheck( temp, 'Naero' )
 
   if(270.16>temp)then
      Naero=Na0*((270.16-temp)**(1.3))
@@ -408,7 +408,7 @@ real function Koenig1( temp )
   real, dimension(32) :: param
   integer :: i
 
-  call ptcheck( temp )
+  call ptcheck( temp, 'Koenig1' )
 
   param=(/0.0,  &
   &       7.939e-11,  &
@@ -467,7 +467,7 @@ real function Koenig2( temp )
   real, dimension(32) :: param
   integer :: i
 
-  call ptcheck( temp )
+  call ptcheck( temp, 'Koenig2' )
 
   param=(/0.0,  &
   &       4.006e-1,  &
@@ -547,10 +547,10 @@ real function Exy( typexy, temp, pres, qc, qx, rhob, rho0, Nx )
   else if(typexy(1:1)=='r')then
      Exy=1.0
   else if(typexy(1:1)=='i')then
-     if(typexy(2:2)=='g')then
-        Exy=0.1
-     else
+     if(typexy(2:2)=='r')then  ! [CReSS orig] Eis and Eig = 0.1
         Exy=1.0
+     else
+        Exy=0.1
      end if
   else if(typexy(1:1)=='s')then
      if(typexy(2:2)=='g')then
@@ -581,7 +581,7 @@ real function Stk( types, temp, pres, qc, qx, rhob, rho0, Nx )
 
   real :: tmpDbc, Dy, Uby, mu
 
-  call ptcheck( temp )
+  call ptcheck( temp, 'Stk' )
 
   if(qc>=qthres.and.qx>=qthres)then
      tmpDbc=Dbc( qc, rhob )
@@ -652,7 +652,7 @@ real function Gw( temp, pres, rhob )
   real, intent(in) :: rhob  ! ̩ [kg/m3]
   real :: tmpa, tmpb, tmpc, tmpd
 
-  call ptcheck( temp )
+  call ptcheck( temp, 'Gw' )
 
   tmpa=Lv(temp)
   tmpb=kappaa*Rv*temp*temp
@@ -675,7 +675,7 @@ real function Gi( temp, pres, rhob )
   real, intent(in) :: rhob  ! ̩ [kg/m3]
   real :: tmpa, tmpb, tmpc, tmpd
 
-  call ptcheck( temp )
+  call ptcheck( temp, 'Gi' )
 
   tmpa=Ls(temp)
   tmpb=kappaa*Rv*temp*temp
@@ -702,7 +702,7 @@ real function VENTx( types, temp, pres, qx, rhob, rho0, Nx )
   real, intent(in), optional :: Nx    ! types οǻ [1/m3]
   real :: tmp, tmpa, tmpb, tmpc, aux, bux, ny0, lamdax
 
-  call ptcheck( temp )
+  call ptcheck( temp, 'VENTx' )
 
   if(qx>=qthres)then
      select case (types(1:1))
@@ -733,6 +733,7 @@ real function VENTx( types, temp, pres, qx, rhob, rho0, Nx )
      tmpb=0.31*(Sc**(1.0/3.0))*sqrt(aux/nu_air( temp, pres ))  &
   &       *gamma_func(tmp)*sqrt(sqrt(rho0/rhob))
      tmpc=exp(-tmp*log(lamdax))
+!     VENTx=rhob*ny0*(tmpa+tmpb*tmpc)  ! [CReSS orig]
      VENTx=ny0*(tmpa+tmpb*tmpc)
 
   else
@@ -795,12 +796,18 @@ real function UbxN( types, qx, rhob, rho0, Nx )
 end function UbxN
 
 
-subroutine ptcheck( temp )
+subroutine ptcheck( temp, rname )
   implicit none
   real, intent(in) :: temp  !  [K]
+  character(*), intent(in), optional :: rname  ! routine name
 
   if(temp>1000.0)then
-     write(*,*) "ERROR ptcheck", temp
+     if(present(rname))then
+        write(*,*) "ERROR ptcheck ("//trim(rname)//')', temp
+     else
+        write(*,*) "ERROR ptcheck", temp
+     end if
+
      stop
   end if
 
@@ -868,6 +875,8 @@ subroutine Moist_Sature_Adjust( pres, pt, qv, qc, err )
   real :: tmppt, tmpqv, tmpqc, dqc, temp, gam, coe, pt1, qv1, qc1, err_max
   real :: tmp_err
 
+  call ptcheck( thetaP_2_T( pt, pres ), 'Moist Sature Adjust' )
+
   if(qv<0.0.or.qc<0.0)then
      write(*,*) "ERROR : Argument in Moist_Sature_Adjust must be greater than zero."
      write(*,*) "STOP."
@@ -932,6 +941,8 @@ subroutine Moist_Sature_Adjust_Ice( pres, pt, qv, qi, err )
   real :: tmppt, tmpqv, tmpqi, dqi, temp, gam, coe, pt1, qv1, qi1, err_max
   real :: tmp_err
 
+  call ptcheck( thetaP_2_T( pt, pres ), 'Moist Sature Adjust Ice' )
+
   if(qv<0.0.or.qi<0.0)then
      write(*,*) "ERROR : Argument in Moist_Sature_Adjust must be greater than zero."
      write(*,*) "STOP."
@@ -980,7 +991,6 @@ subroutine Moist_Sature_Adjust_Ice( pres, pt, qv, qi, err )
   qv=qv1
   qi=qi1
 
-
 end subroutine Moist_Sature_Adjust_Ice
 
 
