@@ -1405,6 +1405,133 @@ end function
 !-----------------------------------------------------
 !-----------------------------------------------------
 
+real function rho_ocean( pres, temp, sal, dl )
+! UNESCO (1981) ξѤ, ̩٤׻.
+! Ǥη׻ˤϰʲΤ褦ʥɺνޤޤƤ뤳Ȥդ.
+!    (a**x)*(b**y)=exp(x*ln(a)+y*ln(b))
+! ʤʤ, 
+!    (a**x)*(b**y)=z
+! => ln{(a**x)*(b**y)}=ln(z)
+! => x*ln(a)+y*ln(b)=ln(z)
+! => exp(x*ln(a)+y*ln(b))=z.
+! Ȥ, c*(b**y) Ȥξ ( x ѿ٤) :
+! c*(b**y)=exp(ln(c)+y*ln(b)) ɽ.
+  implicit none
+  real, intent(in) :: pres    !  [Bar]
+  real, intent(in) :: temp    !  [degC]
+  real, intent(in) :: sal     ! ʬǻ [PSU]
+  integer, intent(in), optional :: dl  ! ǥХå٥
+
+  real :: rhoz0, rhowc, Kw, Kz0, Kz, tmptemp
+
+  if(temp>0.0)then
+     tmptemp=temp
+     Kw=19652.21+148.4206*tmptemp-2.327105*tmptemp*tmptemp  &
+     &  +exp(log(1.360477e-2)+3.0*log(tmptemp))  &
+     &  -exp(log(5.155288e-5)+4.0*log(tmptemp))
+     Kz0=Kw+sal*(54.6746-0.603459*tmptemp  &
+     &          +exp(log(1.09987e-2)+2.0*log(tmptemp))  &
+     &          -exp(log(6.167e-5)+3.0*log(tmptemp)))  &
+     &     +(sal**1.5)*(7.944e-2+1.6483e-2*tmptemp  &
+     &          -exp(log(5.3009e-4)+2.0*log(tmptemp)))
+
+     Kz=Kz0+pres*(3.239908+1.43713e-3*tmptemp  &
+     &           +exp(log(1.16092e-4)+2.0*log(tmptemp))  &
+     &           -exp(log(5.77905e-7)+3.0*log(tmptemp)))  &
+     &     +pres*sal*(2.2838e-3-1.0981e-5*tmptemp  &
+     &           -exp(log(1.6078e-6)+2.0*log(tmptemp)))  &
+     &     +pres*(sal**1.5)*1.91075e-4  &
+     &     +(pres**2)*(8.50935e-5-6.12293e-6*tmptemp  &
+     &           +exp(log(5.2787e-8)+2.0*log(tmptemp)))  &
+     &     +(pres**2)*sal*(-9.9348e-7+2.0816e-8*tmptemp  &
+     &           +exp(log(9.1697e-10)+2.0*log(tmptemp)))
+
+     rhowc=999.842594+6.793952e-2*tmptemp  &
+     &               -exp(log(9.09529e-3)+2.0*log(tmptemp))  &
+     &               +exp(log(1.001685e-4)+3.0*log(tmptemp))  &
+     &               -exp(log(1.120083e-6)+4.0*log(tmptemp))  &
+     &               +exp(log(6.536332e-9)+5.0*log(tmptemp))
+
+     rhoz0=rhowc  &
+     &     +sal*(0.824493-4.0899e-3*tmptemp  &
+     &          +exp(log(7.6438e-5)+2.0*log(tmptemp))  &
+     &          -exp(log(8.2467e-7)+3.0*log(tmptemp))  &
+     &          +exp(log(5.3875e-9)+4.0*log(tmptemp)))  &
+     &     +(sal**1.5)*(-5.72466e-3+1.0227e-4*tmptemp  &
+     &          -exp(log(1.6546e-6)+2.0*log(tmptemp)))  &
+     &     +(sal**2)*4.8314e-4
+
+  else if(temp<0.0)then
+
+     tmptemp=-temp
+     Kw=19652.21-148.4206*tmptemp-2.327105*tmptemp*tmptemp  &
+     &  -exp(log(1.360477e-2)+3.0*log(tmptemp))  &
+     &  -exp(log(5.155288e-5)+4.0*log(tmptemp))
+
+     Kz0=Kw+sal*(54.6746+0.603459*tmptemp  &
+     &          +exp(log(1.09987e-2)+2.0*log(tmptemp))  &
+     &          +exp(log(6.167e-5)+3.0*log(tmptemp)))  &
+     &     +(sal**1.5)*(7.944e-2-1.6483e-2*tmptemp  &
+     &          -exp(log(5.3009e-4)+2.0*log(tmptemp)))
+
+     Kz=Kz0+pres*(3.239908-1.43713e-3*tmptemp  &
+     &           +exp(log(1.16092e-4)+2.0*log(tmptemp))  &
+     &           +exp(log(5.77905e-7)+3.0*log(tmptemp)))  &
+     &     +pres*sal*(2.2838e-3+1.0981e-5*tmptemp  &
+     &           -exp(log(1.6078e-6)+2.0*log(tmptemp)))  &
+     &     +pres*(sal**1.5)*1.91075e-4  &
+     &     +(pres**2)*(8.50935e-5+6.12293e-6*tmptemp  &
+     &           +exp(log(5.2787e-8)+2.0*log(tmptemp)))  &
+     &     +(pres**2)*sal*(-9.9348e-7-2.0816e-8*tmptemp  &
+     &           +exp(log(9.1697e-10)+2.0*log(tmptemp)))
+
+     rhowc=999.842594-6.793952e-2*tmptemp  &
+     &               -exp(log(9.09529e-3)+2.0*log(tmptemp))  &
+     &               -exp(log(1.001685e-4)+3.0*log(tmptemp))  &
+     &               -exp(log(1.120083e-6)+4.0*log(tmptemp))  &
+     &               -exp(log(6.536332e-9)+5.0*log(tmptemp))
+
+     rhoz0=rhowc  &
+     &     +sal*(0.824493+4.0899e-3*tmptemp  &
+     &          +exp(log(7.6438e-5)+2.0*log(tmptemp))  &
+     &          +exp(log(8.2467e-7)+3.0*log(tmptemp))  &
+     &          +exp(log(5.3875e-9)+4.0*log(tmptemp)))  &
+     &     +(sal**1.5)*(-5.72466e-3-1.0227e-4*tmptemp  &
+     &          -exp(log(1.6546e-6)+2.0*log(tmptemp)))  &
+     &     +(sal**2)*4.8314e-4
+
+  else
+
+     Kw=19652.21
+     Kz0=Kw+sal*(54.6746  &
+     &     +(sal**1.5)*7.944e-2)
+     Kz=Kz0+pres*3.239908  &
+     &     +pres*sal*2.2838e-3  &
+     &     +pres*(sal**1.5)*1.91075e-4  &
+     &     +(pres**2)*8.50935e-5  &
+     &     +(pres**2)*sal*(-9.9348e-7)
+
+     rhowc=999.842594
+
+     rhoz0=rhowc  &
+     &     +sal*0.824493  &
+     &     -5.72466e-3*(sal**1.5)  &
+     &     +4.8314e-4*(sal**2)
+
+  end if
+
+  rho_ocean=rhoz0/(1.0-pres/Kz)
+
+  if(present(dl))then
+     call debug_flag_r( dl, 'Thermo_Function', 'rho_ocean', rho_ocean, 'kg m-3' )
+  end if
+
+  return
+end function rho_ocean
+
+!-----------------------------------------------------
+!-----------------------------------------------------
+
 !real function
 
 
